#ifndef OVERWRITEDIALOG_H
#define OVERWRITEDIALOG_H

#include <QDialog>

namespace Ui {
    class overwriteDialog;
}

class overwriteDialog : public QDialog
{
    Q_OBJECT

    friend class wpNew;

public:
    explicit overwriteDialog(QWidget *parent = 0);
    ~overwriteDialog();

protected:
    Ui::overwriteDialog *ui;
};

#endif // OVERWRITEDIALOG_H
